@@ -24,15 +24,11 @@ import zope.app.wsgi
 
 class Layer(gocept.selenium.base.Layer):
 
-    # Hostname and port of the Zope webserver
-    host = 'localhost'
-    port = 8087
-
     def setUp(self):
         task_dispatcher = ThreadedTaskDispatcher()
         task_dispatcher.setThreadCount(1)
         db = zope.app.testing.functional.FunctionalTestSetup().db
-        self.http = SwitchableDBServerType.create(
+        self.http = zope.app.server.wsgi.http.create(
             'WSGI-HTTP', task_dispatcher, db, port=self.port)
         self.thread = threading.Thread(target=self.run_server)
         self.thread.setDaemon(True)
@@ -50,39 +46,18 @@ class Layer(gocept.selenium.base.Layer):
             asyncore.poll(0.1)
         self.http.close()
 
-    def switch_db(self):
-        """switches the HTTP-server's database to the currently active
-        DemoStorage"""
-        db = zope.app.testing.functional.FunctionalTestSetup().db
-        self.http.application.set_db(db)
-
 
 class TestCase(gocept.selenium.base.TestCase,
                zope.app.testing.functional.FunctionalTestCase):
     # note: MRO requires the gocept.selenium.base.TestCase to come first,
     # otherwise setUp/tearDown happens in the wrong order
-    pass
 
-
-class SwitchableDBApplication(zope.app.wsgi.WSGIPublisherApplication):
-
-    def __init__(self, *args, **kw):
-        self.db = kw.get('db', None)
-        super(SwitchableDBApplication, self).__init__(*args, **kw)
-
-    def __call__(self, environ, start_response):
-        if self.db is not None:
-            factory = type(self.requestFactory)
-            self.requestFactory = factory(self.db)
-        return super(SwitchableDBApplication, self).__call__(
-            environ, start_response)
-
-    def set_db(self, db):
-        self.db = db
-
-
-SwitchableDBServerType = zope.app.server.wsgi.ServerType(
-    zope.server.http.wsgihttpserver.WSGIHTTPServer,
-    SwitchableDBApplication,
-    zope.server.http.commonaccesslogger.CommonAccessLogger,
-    8087, True)  # The port number here is just the default value
+    def setUp(self):
+        # switches the HTTP-server's database to the currently active
+        # DemoStorage (which is set by FunctionalTestCase)
+        super(TestCase, self).setUp()
+        db = zope.app.testing.functional.FunctionalTestSetup().db
+        application = self.layer.http.application
+        assert isinstance(application, zope.app.wsgi.WSGIPublisherApplication)
+        factory = type(application.requestFactory)
+        application.requestFactory = factory(db)
